@@ -32,17 +32,13 @@ private slots:
     void replyFinished(QNetworkReply*);
 
 private:
-    //QWebView *m_webView;
     QLabel *m_address;
-
     QNetworkAccessManager *m_networkManager;
-
     QVBoxLayout *m_layout;
 
-    //QString m_html;
-
     Latitude latitude;
     LatitudeSettings *m_settingsDialog;
+    QSettings oauthSettings;
 
 #ifndef Q_WS_MAEMO_5
     QPushButton *m_settingsButton;
