@@ -2,12 +2,16 @@
 #define LATITUDESETTINGS_H
 
 #include <QDialog>
+#include <QtLocation/QGeoPositionInfoSource>
 
 class QPushButton;
 class QLabel;
 class QHBoxLayout;
 class QVBoxLayout;
 class QSpinBox;
+class QComboBox;
+
+using namespace QtMobility;
 
 class LatitudeSettings : public QDialog
 {
@@ -17,7 +21,10 @@ public:
     ~LatitudeSettings();
 
     int updateInterval();
+    QGeoPositionInfoSource::PositioningMethod positioningMethod();
 
+    void setUpdateIterval(int minutes);
+    void setPositioningMethod(QGeoPositionInfoSource::PositioningMethod method);
 signals:
     void authorize();
 
@@ -30,7 +37,9 @@ private:
     QPushButton *m_authButton;
     QHBoxLayout *m_hlayout1;
     QHBoxLayout *m_hlayout2;
+    QHBoxLayout *m_hlayout3;
     QVBoxLayout *m_vlayout;
+    QComboBox *m_method;
     QSpinBox *m_refresh;
     QPushButton *m_okButton;
 };
